PPCompositeParserTest subclass: #PPCompoClassesTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Compo-Parser-Tests'!
!PPCompoClassesTests commentStamp: 'lr 3/26/2009 16:09' prior: 0!
Evalaute the following code to verify the complete image.

PackageOrganizer default packages
	inject: LAPackagesTests new
	into: [ :test :package | 
		[ test verifyPackage: package packageName ]
			on: TestResult resumableFailure
			do: [ :err | err resume ] ]!


!PPCompoClassesTests methodsFor: 'private' stamp: 'lr 9/27/2009 12:43'!
assert: aBoolean description: aString 
	self 
		assert: aBoolean
		description: aString
		resumable: true! !

!PPCompoClassesTests methodsFor: 'private' stamp: 'lr 5/1/2010 16:28'!
verifyClass: aClass 
	aClass selectors 
		do: [ :selector | self verifyClass: aClass selector: selector ].
	aClass isMeta
		ifFalse: [ self verifyClass: aClass class ]! !

!PPCompoClassesTests methodsFor: 'private' stamp: 'lr 5/1/2012 09:32'!
verifyClass: aClass selector: aSelector 
	"Verifies that the method aSelector in aClass parses the same using the standard refactoring parser and the petit smalltalk parser. Also make sure that the position information of all tokens and comments is equal."

	| signature source original other checker |
	signature := aClass name , '>>#' , aSelector.
	source := aClass sourceCodeAt: aSelector.
	source isNil ifTrue: [ ^ self ].
	original := aClass parseTreeFor: aSelector.
	original isNil ifTrue: [ ^ self ].
	other := self parserInstance
		parseMethod: source
		onError: [ :err | self assert: false description: signature ].
	self 
		assert: original = other
		description: 'Code in ' , signature.
	checker := [ :node1 :node2 |
		self 
			assert: node1 sourceInterval = node2 sourceInterval 
			description: 'Source intervals in ' , signature.
		(node1 isArray or: [ node1 isBlock or: [ node1 isPragma ] ]) ifTrue: [
			self
				assert: node1 left = node2 left
				description: 'Source position left in ' , signature.
			self
				assert: node1 right = node2 right
				description: 'Source position right in ' , signature ].
		(node1 isSequence) ifTrue: [
			self
				assert: node1 leftBar = node2 leftBar
				description: 'Source position leftBar in ' , signature.
			self
				assert: node1 rightBar = node2 rightBar
				description: 'Source position rightBar in ' , signature ].
		(node1 isBlock) ifTrue: [
			self
				assert: node1 bar = node2 bar
				description: 'Source position bar in ' , signature ].
		(node1 isReturn) ifTrue: [
			self
				assert: node1 return = node2 return
				description: 'Source position return in ' , signature ].
		(node1 isAssignment) ifTrue: [
			self
				assert: node1 assignment = node2 assignment
				description: 'Source position return in ' , signature ].
		(node1 isCascade) ifTrue: [
			self
				assert: node1 semicolons asArray = node2 semicolons asArray
				description: 'Source position semicolons in ' , signature ].
		(node1 isArray or: [ node1 isSequence ]) ifTrue: [
			self
				assert: node1 periods asArray = node2 periods asArray
				description: 'Source position periods in ' , signature ].
		(node1 isMethod or: [ node1 isMessage or: [ node1 isPragma ] ]) ifTrue: [
			node1 selectorParts with: node2 selectorParts do: [ :a :b |
				self
					assert: a start = b start
					description: 'Source position selector parts in ' , signature ] ].
		node1 children with: node2 children do: checker ].
	checker value: original value: other! !


!PPCompoClassesTests methodsFor: 'accessing' stamp: 'PetrSpacek 10/17/2012 15:20'!
parserClass
	^ PPCompoParser! !


!PPCompoClassesTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testCollection
	self verifyClass: Collection.
	self verifyClass: Array.
	self verifyClass: Set.
	self verifyClass: Dictionary.
	self verifyClass: Bag.
	self verifyClass: OrderedCollection.
	self verifyClass: SortedCollection! !

!PPCompoClassesTests methodsFor: 'testing' stamp: 'TestRunner 10/23/2009 18:12'!
testException
	self verifyClass: Exception.
	self verifyClass: Notification.
	self verifyClass: Warning.
	self verifyClass: Error! !

!PPCompoClassesTests methodsFor: 'testing' stamp: 'TestRunner 10/23/2009 18:12'!
testFundamental
	self verifyClass: Object.
	self verifyClass: Boolean.
	self verifyClass: True.
	self verifyClass: False.
	self verifyClass: Character


! !

!PPCompoClassesTests methodsFor: 'testing' stamp: 'TestRunner 10/23/2009 18:10'!
testMagnitude
	self verifyClass: Magnitude.
	self verifyClass: Number.
	self verifyClass: Integer.
	self verifyClass: Float.
	self verifyClass: Fraction! !

!PPCompoClassesTests methodsFor: 'testing' stamp: 'TestRunner 10/23/2009 18:14'!
testStream
	self verifyClass: Stream.
	self verifyClass: ReadStream.
	self verifyClass: WriteStream! !


!PPCompoClassesTests methodsFor: 'testing-protocol' stamp: 'lr 2/19/2010 09:13'!
testParseExpression
	result := self parserClass parseExpression: '1 + 2'.
	self assert: result isMessage.
	self assert: result source = '1 + 2'.
	
	result := self parserClass parseExpression: '| a | 1 + a'.
	self assert: result isSequence.
	self assert: result source =  '| a | 1 + a'.
	
	result := self parserClass parseExpression: '1 + 2. ^ 3'.
	self assert: result isSequence.
	self assert: result source = '1 + 2. ^ 3'.
	
	result := self parserClass parseExpression: '1 + ' onError: [ :err | true ].
	self assert: result.
	
	self 
		should: [ self parserClass parseExpression: '1 + ' ] 
		raise: Error! !

!PPCompoClassesTests methodsFor: 'testing-protocol' stamp: 'lr 2/19/2010 09:13'!
testParseMethod
	result := self parserClass parseMethod: 'do 1 + 2'.
	self assert: result isMethod.
	self assert: result source = 'do 1 + 2'.
	
	result := self parserClass parseMethod: 'do 1 +' onError: [ :err | true ].
	self assert: result.
	
	self 
		should: [ self parserClass parseMethod: 'do 1 +' ]
		raise: Error! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

PPCompoClassesTests class
	instanceVariableNames: ''!

!PPCompoClassesTests class methodsFor: 'utilities' stamp: 'lr 8/14/2011 13:32'!
benchmark: aParser
	"self benchmark: PPSmalltalkGrammar new"
	"self benchmark: PPSmalltalkParser new"
	"self benchmark: RBParser"
	
	| sources |
	sources := OrderedCollection new.
	SequenceableCollection withAllSubclassesDo: [ :class |
		class selectors do: [ :selector |
			sources add: (class sourceCodeAt: selector) ] ].
	^ self benchmark: aParser sources: sources asArray! !

!PPCompoClassesTests class methodsFor: 'utilities' stamp: 'lr 8/17/2011 23:56'!
benchmark: aParser sources: aCollection
	| count start |
	count := 0.
	start := Time millisecondClockValue.
	[  aCollection do: [ :each | aParser parseMethod: each ].
		count := count + 1.
		(Time millisecondsSince: start) < 10000 ] whileTrue.
	^ (1000 * count * (aCollection detectSum: [ :each | each size ]) 
		/ (Time millisecondsSince: start)) asInteger asString , ' characters/sec'! !

!PPCompoClassesTests class methodsFor: 'utilities' stamp: 'lr 8/11/2011 23:41'!
verifySystem
	Smalltalk globals allClasses
		inject: self new
		into: [ :test :class | test verifyClass: class ]! !


!PPCompoClassesTests class methodsFor: 'accessing' stamp: 'lr 11/29/2010 11:36'!
packageNamesUnderTest
	^ #('PetitSmalltalk')! !


PPCompositeParserTest subclass: #PPCompoGrammarTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Compo-Parser-Tests'!

!PPCompoGrammarTests methodsFor: 'accessing' stamp: 'PetrSpacek 10/17/2012 15:20'!
parserClass
	^ PPCompoGrammar! !


!PPCompoGrammarTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testArgumentsBlock1
	self 
		parse: '[ :a | ]'
		rule: #block! !

!PPCompoGrammarTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testArgumentsBlock2
	self 
		parse: '[ :a :b | ]'
		rule: #block! !

!PPCompoGrammarTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testArgumentsBlock3
	self 
		parse: '[ :a :b :c | ]'
		rule: #block! !

!PPCompoGrammarTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testComplexBlock1
	self 
		parse: '[ :a | | b | c ]'
		rule: #block! !

!PPCompoGrammarTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testComplexBlock2
	self 
		parse: '[:a||b|c]'
		rule: #block! !

!PPCompoGrammarTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testSimpleBlock1
	self 
		parse: '[ ]'
		rule: #block! !

!PPCompoGrammarTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testSimpleBlock2
	self 
		parse: '[ nil ]'
		rule: #block! !

!PPCompoGrammarTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testSimpleBlock3
	self 
		parse: '[ :a ]'
		rule: #block! !

!PPCompoGrammarTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testStatementBlock1
	self 
		parse: '[ nil ]'
		rule: #block! !

!PPCompoGrammarTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testStatementBlock2
	self 
		parse: '[ | a | nil ]'
		rule: #block! !

!PPCompoGrammarTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testStatementBlock3
	self 
		parse: '[ | a b | nil ]'
		rule: #block! !


!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 3/1/2010 10:09'!
testArray1
	self 
		parse: '{}'
		rule: #array! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 3/1/2010 10:10'!
testArray2
	self 
		parse: '{self foo}'
		rule: #array! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 3/1/2010 10:10'!
testArray3
	self 
		parse: '{self foo. self bar}'
		rule: #array! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 3/1/2010 10:10'!
testArray4
	self 
		parse: '{self foo. self bar.}'
		rule: #array! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testAssignment1
	self 
		parse: '1'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testAssignment2
	self 
		parse: 'a := 1'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testAssignment3
	self 
		parse: 'a := b := 1'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'PetrSpacek 10/17/2012 15:20'!
testAssignment4
	PPCompoGrammar allowUnderscoreAssignment
		ifTrue: [ self parse: 'a _ 1' rule: #expression ]
		ifFalse: [ self fail: 'a _ 1' rule: #expression ]! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'PetrSpacek 10/17/2012 15:20'!
testAssignment5
	PPCompoGrammar allowUnderscoreAssignment
		ifTrue: [ self parse: 'a _ b _ 1' rule: #expression ]
		ifFalse: [ self fail: 'a _ b _ 1' rule: #expression ]! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 11/23/2010 14:03'!
testAssignment6
	self 
		parse: 'a := (b := c)'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testComment1
	self 
		parse: '1"one"+2'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testComment2
	self 
		parse: '1 "one" +2'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testComment3
	self 
		parse: '1"one"+"two"2'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testComment4
	self 
		parse: '1"one""two"+2'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testComment5
	self 
		parse: '1"one"	"two"+2'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 8/17/2011 23:57'!
testCompleteness
	"This test asserts that all subclasses override all test methods."
	
	self class allSubclasses do: [ :subclass |
		self class testSelectors do: [ :selector |
			self 
				assert: (selector = #testCompleteness or: [ subclass selectors includes: selector ])
				description: subclass printString , ' does not test ' , selector printString ] ]! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testMethod1
	self 
		parse: 'negated ^ 0 - self'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testMethod2
	"Spaces at the beginning of the method."
	self 
		parse: '	  negated ^ 0 - self'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testMethod3
	"Spaces at the end of the method."
	self 
		parse: '	negated ^ 0 - self  '
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testSequence1
	self 
		parse: '| a | 1 . 2'
		rule: #sequence! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testStatements1
	self 
		parse: '1'
		rule: #sequence! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testStatements2
	self 
		parse: '1 . 2'
		rule: #sequence! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testStatements3
	self 
		parse: '1 . 2 . 3'
		rule: #sequence! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testStatements4
	self 
		parse: '1 . 2 . 3 .'
		rule: #sequence! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testStatements5
	self 
		parse: '1 . . 2'
		rule: #sequence! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 8/13/2011 20:45'!
testStatements6
	self 
		parse: '1. 2'
		rule: #sequence! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 8/13/2011 20:46'!
testStatements7
	self 
		parse: '. 1'
		rule: #sequence! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 8/13/2011 20:46'!
testStatements8
	self 
		parse: '.1'
		rule: #sequence! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testTemporaries1
	self 
		parse: '| a |'
		rule: #sequence! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testTemporaries2
	self 
		parse: '| a b |'
		rule: #sequence! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testTemporaries3
	self 
		parse: '| a b c |'
		rule: #sequence! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testVariable1
	self 
		parse: 'trueBinding'
		rule: #primary! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testVariable2
	self 
		parse: 'falseBinding'
		rule: #primary! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testVariable3
	self 
		parse: 'nilly'
		rule: #primary! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testVariable4
	self 
		parse: 'selfish'
		rule: #primary! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testVariable5
	self 
		parse: 'supernanny'
		rule: #primary! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'PetrSpacek 10/17/2012 15:20'!
testVariable6
	PPCompoGrammar allowUnderscoreAssignment ifFalse: [
		self 
			parse: 'super_nanny'
			rule: #primary ]! !

!PPCompoGrammarTests methodsFor: 'testing' stamp: 'PetrSpacek 10/17/2012 15:20'!
testVariable7
	PPCompoGrammar allowUnderscoreAssignment ifFalse: [
		self 
			parse: '__gen_var_123__'
			rule: #primary ]! !


!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral1
	self 
		parse: '#()'
		rule: #arrayLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral10
	self 
		parse: '#((1 2) #(1 2 3))'
		rule: #arrayLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral11
	self 
		parse: '#([1 2] #[1 2 3])'
		rule: #arrayLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral2
	self 
		parse: '#(1)'
		rule: #arrayLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral3
	self 
		parse: '#(1 2)'
		rule: #arrayLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral4
	self 
		parse: '#(true false nil)'
		rule: #arrayLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral5
	self 
		parse: '#($a)'
		rule: #arrayLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral6
	self 
		parse: '#(1.2)'
		rule: #arrayLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral7
	self 
		parse: '#(size #at: at:put: #''=='')'
		rule: #arrayLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral8
	self 
		parse: '#(''baz'')'
		rule: #arrayLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'TestRunner 10/23/2009 16:52'!
testArrayLiteral9
	self 
		parse: '#((1) 2)'
		rule: #arrayLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testByteLiteral1
	self 
		parse: '#[]'
		rule: #byteLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testByteLiteral2
	self 
		parse: '#[0]'
		rule: #byteLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testByteLiteral3
	self 
		parse: '#[255]'
		rule: #byteLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testByteLiteral4
	self 
		parse: '#[ 1 2 ]'
		rule: #byteLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testByteLiteral5
	self 
		parse: '#[ 2r1010 8r77 16rFF ]'
		rule: #byteLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testCharLiteral1
	self 
		parse: '$a'
		rule: #charLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testCharLiteral2
	self 
		parse: '$ '
		rule: #charLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testCharLiteral3
	self 
		parse: '$$'
		rule: #charLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testNumberLiteral1
	self 
		parse: '0'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testNumberLiteral10
	self 
		parse: '10r10'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testNumberLiteral11
	self 
		parse: '8r777'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testNumberLiteral12
	self 
		parse: '16rAF'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testNumberLiteral13
	self 
		parse: '16rCA.FE'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testNumberLiteral14
	self 
		parse: '3r-22.2'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 8/13/2011 20:40'!
testNumberLiteral15
	self 
		parse: '0.50s2'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testNumberLiteral2
	self 
		parse: '0.1'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testNumberLiteral3
	self 
		parse: '123'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testNumberLiteral4
	self 
		parse: '123.456'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testNumberLiteral5
	self 
		parse: '-0'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testNumberLiteral6
	self 
		parse: '-0.1'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testNumberLiteral7
	self 
		parse: '-123'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testNumberLiteral8
	self 
		parse: '-123'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testNumberLiteral9
	self 
		parse: '-123.456'
		rule: #numberLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testSpecialLiteral1
	self 
		parse: 'true'
		rule: #trueLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testSpecialLiteral2
	self 
		parse: 'false'
		rule: #falseLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testSpecialLiteral3
	self 
		parse: 'nil'
		rule: #nilLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testStringLiteral1
	self 
		parse: ''''''
		rule: #stringLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testStringLiteral2
	self 
		parse: '''ab'''
		rule: #stringLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testStringLiteral3
	self 
		parse: '''ab''''cd'''
		rule: #stringLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testSymbolLiteral1
	self 
		parse: '#foo'
		rule: #symbolLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testSymbolLiteral2
	self 
		parse: '#+'
		rule: #symbolLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testSymbolLiteral3
	self 
		parse: '#key:'
		rule: #symbolLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testSymbolLiteral4
	self 
		parse: '#key:value:'
		rule: #symbolLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testSymbolLiteral5
	self 
		parse: '#''testing-result'''
		rule: #symbolLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'PetrSpacek 10/17/2012 15:20'!
testSymbolLiteral6
	PPCompoGrammar allowUnderscoreAssignment ifFalse: [
		self 
			parse: '#__gen__binding'
			rule: #symbolLiteral ]! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:26'!
testSymbolLiteral7
	self 
		parse: '# fucker'
		rule: #symbolLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:26'!
testSymbolLiteral8
	self 
		parse: '##fucker'
		rule: #symbolLiteral! !

!PPCompoGrammarTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:26'!
testSymbolLiteral9
	self 
		parse: '## fucker'
		rule: #symbolLiteral! !


!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testBinaryExpression1
	self 
		parse: '1 + 2'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testBinaryExpression2
	self 
		parse: '1 + 2 + 3'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'DamienPollet 8/11/2011 22:20'!
testBinaryExpression3
	self 
		parse: '1 // 2'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 8/11/2011 23:28'!
testBinaryExpression4
	self 
		parse: '1 -- 2'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 8/11/2011 23:25'!
testBinaryExpression5
	self 
		parse: '1 ==> 2'
		rule: #expression.! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testBinaryMethod1
	self 
		parse: '+ a'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testBinaryMethod2
	self 
		parse: '+ a | b |'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testBinaryMethod3
	self 
		parse: '+ a b'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testBinaryMethod4
	self 
		parse: '+ a | b | c'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 8/11/2011 23:28'!
testBinaryMethod5
	self 
		parse: '-- a'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testCascadeExpression1
	self 
		parse: '1 abs; negated'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testCascadeExpression2
	self 
		parse: '1 abs negated; raisedTo: 12; negated'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testCascadeExpression3
	self 
		parse: '1 + 2; - 3'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testKeywordExpression1
	self 
		parse: '1 to: 2'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testKeywordExpression2
	self 
		parse: '1 to: 2 by: 3'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testKeywordExpression3
	self 
		parse: '1 to: 2 by: 3 do: 4'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testKeywordMethod1
	self 
		parse: 'to: a'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testKeywordMethod2
	self 
		parse: 'to: a do: b | c |'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testKeywordMethod3
	self 
		parse: 'to: a do: b by: c d'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testKeywordMethod4
	self 
		parse: 'to: a do: b by: c | d | e'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testUnaryExpression1
	self 
		parse: '1 abs'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testUnaryExpression2
	self 
		parse: '1 abs negated'
		rule: #expression! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testUnaryMethod1
	self 
		parse: 'abs'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testUnaryMethod2
	self 
		parse: 'abs | a |'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testUnaryMethod3
	self 
		parse: 'abs a'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testUnaryMethod4
	self 
		parse: 'abs | a | b'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testUnaryMethod5
	self 
		parse: 'abs | a |'
		rule: #method! !


!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma1
	self 
		parse: 'method <foo>'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma10
	self 
		parse: 'method <foo: bar>'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma11
	self 
		parse: 'method <foo: true>'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma12
	self 
		parse: 'method <foo: false>'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma13
	self 
		parse: 'method <foo: nil>'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma14
	self 
		parse: 'method <foo: ()>'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 11/23/2010 13:59'!
testPragma15
	self 
		parse: 'method <foo: #()>'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 11/23/2010 13:59'!
testPragma16
	self 
		parse: 'method < + 1 >'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma2
	self 
		parse: 'method <foo> <bar>'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma3
	self 
		parse: 'method | a | <foo>'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma4
	self 
		parse: 'method <foo> | a |'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma5
	self 
		parse: 'method <foo> | a | <bar>'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma6
	self 
		parse: 'method <foo: 1>'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma7
	self 
		parse: 'method <foo: 1.2>'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma8
	self 
		parse: 'method <foo: ''bar''>'
		rule: #method! !

!PPCompoGrammarTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma9
	self 
		parse: 'method <foo: #''bar''>'
		rule: #method! !

"-- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- "!

PPCompoGrammarTests class
	instanceVariableNames: ''!

!PPCompoGrammarTests class methodsFor: 'accessing' stamp: 'lr 11/29/2010 11:36'!
packageNamesUnderTest
	^ #('PetitSmalltalk')! !


PPCompoGrammarTests subclass: #PPCompoParserTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Compo-Parser-Tests'!

!PPCompoParserTests methodsFor: 'private' stamp: 'lr 2/29/2012 19:23'!
assert: aNode format: aString 
	aNode isCollection 
		ifFalse: [ ^ self assert: (Array with: aNode) format: (Array with: aString) ].
	self assert: aNode size = aString size.
	aNode
		with: aString
		do: [ :node :string | self assert: (RBFormatter new format: node) = string ]! !


!PPCompoParserTests methodsFor: 'accessing' stamp: 'PetrSpacek 10/17/2012 15:20'!
parserClass
	^ PPCompoParser! !


!PPCompoParserTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testArgumentsBlock1
	super testArgumentsBlock1.
	self assert: result isBlock.
	self assert: result arguments size = 1.
	self assert: result arguments first isVariable.
	self assert: result arguments first name = 'a'.
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testArgumentsBlock2
	super testArgumentsBlock2.
	self assert: result isBlock.
	self assert: result arguments size = 2.
	self assert: result arguments first isVariable.
	self assert: result arguments first name = 'a'.
	self assert: result arguments second isVariable.
	self assert: result arguments second name = 'b'.
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testArgumentsBlock3
	super testArgumentsBlock3.
	self assert: result isBlock.
	self assert: result arguments size = 3.
	self assert: result arguments first isVariable.
	self assert: result arguments first name = 'a'.
	self assert: result arguments second isVariable.
	self assert: result arguments second name = 'b'.
	self assert: result arguments third isVariable.
	self assert: result arguments third name = 'c'.
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testComplexBlock1
	super testComplexBlock1.
	self assert: result isBlock.
	self assert: result arguments size = 1.
	self assert: result body temporaries size = 1.
	self assert: result body statements size = 1! !

!PPCompoParserTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testComplexBlock2
	super testComplexBlock2.
	self assert: result isBlock.
	self assert: result arguments size = 1.
	self assert: result body temporaries size = 1.
	self assert: result body statements size = 1! !

!PPCompoParserTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testSimpleBlock1
	super testSimpleBlock1.
	self assert: result isBlock.
	self assert: result arguments isEmpty.
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testSimpleBlock2
	super testSimpleBlock2.
	self assert: result isBlock.
	self assert: result arguments isEmpty.
	self assert: result body temporaries isEmpty.
	self assert: result body statements size = 1! !

!PPCompoParserTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testSimpleBlock3
	super testSimpleBlock3.
	self assert: result isBlock.
	self assert: result arguments size = 1.
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testStatementBlock1
	super testStatementBlock1.
	self assert: result isBlock.
	self assert: result arguments isEmpty.
	self assert: result body temporaries isEmpty.
	self assert: result body statements size = 1! !

!PPCompoParserTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testStatementBlock2
	super testStatementBlock2.
	self assert: result isBlock.
	self assert: result arguments isEmpty.
	self assert: result body temporaries size = 1.
	self assert: result body statements size = 1! !

!PPCompoParserTests methodsFor: 'testing-blocks' stamp: 'lr 9/27/2009 12:42'!
testStatementBlock3
	super testStatementBlock3.
	self assert: result isBlock.
	self assert: result arguments isEmpty.
	self assert: result body temporaries size = 2.
	self assert: result body statements size = 1! !


!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 3/1/2010 10:13'!
testArray1
	super testArray1.
	self assert: result isArray.
	self assert: result statements isEmpty.
	self assert: result periods isEmpty! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 3/1/2010 10:13'!
testArray2
	super testArray2.
	self assert: result isArray.
	self assert: result periods isEmpty.
	self assert: result statements size = 1.
	self assert: result statements first isMessage.
	self assert: result statements first selector = #foo! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 3/1/2010 10:14'!
testArray3
	super testArray3.
	self assert: result isArray.
	self assert: result periods size = 1.
	self assert: result statements size = 2.
	self assert: result statements first isMessage.
	self assert: result statements first selector = #foo.
	self assert: result statements last isMessage.
	self assert: result statements last selector = #bar! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 3/1/2010 10:14'!
testArray4
	super testArray4.
	self assert: result isArray.
	self assert: result periods size = 2.
	self assert: result statements size = 2.
	self assert: result statements first isMessage.
	self assert: result statements first selector = #foo.
	self assert: result statements last isMessage.
	self assert: result statements last selector = #bar! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testAssignment1
	super testAssignment1.
	self assert: result isLiteral.
	self assert: result value = 1! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testAssignment2
	super testAssignment2.
	self assert: result isAssignment.
	self assert: result variable isVariable.
	self assert: result variable name = 'a'.
	self assert: result value isLiteral.
	self assert: result value value = 1! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testAssignment3
	super testAssignment3.
	self assert: result isAssignment.
	self assert: result variable isVariable.
	self assert: result variable name = 'a'.
	self assert: result value isAssignment.
	self assert: result value variable isVariable.
	self assert: result value variable name = 'b'.
	self assert: result value value isLiteral.
	self assert: result value value value = 1! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'PetrSpacek 10/17/2012 15:20'!
testAssignment4
	super testAssignment4.
	PPCompoGrammar allowUnderscoreAssignment
		ifFalse: [ ^ self ].
	self assert: result isAssignment.
	self assert: result variable isVariable.
	self assert: result variable name = 'a'.
	self assert: result value isLiteral.
	self assert: result value value = 1! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'PetrSpacek 10/17/2012 15:20'!
testAssignment5
	super testAssignment5.
	PPCompoGrammar allowUnderscoreAssignment
		ifFalse: [ ^ self ].
	self assert: result isAssignment.
	self assert: result variable isVariable.
	self assert: result variable name = 'a'.
	self assert: result value isAssignment.
	self assert: result value variable isVariable.
	self assert: result value variable name = 'b'.
	self assert: result value value isLiteral.
	self assert: result value value value = 1! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 11/23/2010 14:02'!
testAssignment6
	super testAssignment6.
	self assert: result isAssignment.
	self assert: result variable isVariable.
	self assert: result variable name = 'a'.
	self assert: result value isAssignment.
	self assert: result value variable isVariable.
	self assert: result value variable name = 'b'.
	self assert: result value value isVariable.
	self assert: result value value name = 'c'! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 3/1/2010 10:20'!
testComment1
	super testComment1.
	self assert: result isMessage.
	self assert: result receiver isValue.
	self assert: result selector = #+.
	self assert: result arguments first isValue! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testComment2
	super testComment2.
	self assert: result isMessage.
	self assert: result receiver isValue.
	self assert: result selector = #+.
	self assert: result arguments first isValue! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testComment3
	super testComment3.
	self assert: result isMessage.
	self assert: result receiver isValue.
	self assert: result selector = #+.
	self assert: result arguments first isValue! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testComment4
	super testComment4.
	self assert: result isMessage.
	self assert: result receiver isValue.
	self assert: result selector = #+.
	self assert: result arguments first isValue! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testComment5
	super testComment5.
	self assert: result isMessage.
	self assert: result receiver isValue.
	self assert: result selector = #+.
	self assert: result arguments first isValue! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testMethod1
	super testMethod1.
	self assert: result isMethod.
	self assert: result arguments isEmpty.
	self assert: result body temporaries isEmpty.
	self assert: result body statements size = 1.
	self assert: result body statements first isReturn.
	self assert: result body statements first value isMessage.
	self assert: result body statements first value receiver isLiteral.
	self assert: result body statements first value selector = #-.
	self assert: result body statements first value arguments size = 1.
	self assert: result body statements first value arguments first isVariable! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testMethod2
	super testMethod2.
	self assert: result isMethod.
	self assert: result arguments isEmpty.
	self assert: result body temporaries isEmpty.
	self assert: result body statements size = 1.
	self assert: result body statements first isReturn.
	self assert: result body statements first value isMessage.
	self assert: result body statements first value receiver isLiteral.
	self assert: result body statements first value selector = #-.
	self assert: result body statements first value arguments size = 1.
	self assert: result body statements first value arguments first isVariable! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testMethod3
	super testMethod3.
	self assert: result isMethod.
	self assert: result arguments isEmpty.
	self assert: result body temporaries isEmpty.
	self assert: result body statements size = 1.
	self assert: result body statements first isReturn.
	self assert: result body statements first value isMessage.
	self assert: result body statements first value receiver isLiteral.
	self assert: result body statements first value selector = #-.
	self assert: result body statements first value arguments size = 1.
	self assert: result body statements first value arguments first isVariable! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testSequence1
	super testSequence1.
	self assert: result isSequence.
	self assert: result temporaries size = 1.
	self assert: result temporaries first isVariable.
	self assert: result temporaries first name = 'a'.
	self assert: result statements size = 2.
	self assert: result statements first isLiteral.
	self assert: result statements first value = 1.
	self assert: result statements second isLiteral.
	self assert: result statements second value = 2! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 8/13/2011 20:50'!
testStatements1
	super testStatements1.
	self assert: result isSequence.
	self assert: result temporaries isEmpty.
	self assert: result statements size = 1.
	self assert: result statements first isLiteral.
	self assert: result statements first value = 1.
	self assert: result statements first value isInteger! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 8/13/2011 20:50'!
testStatements2
	super testStatements2.
	self assert: result isSequence.
	self assert: result temporaries isEmpty.
	self assert: result statements size = 2.
	self assert: result statements first isLiteral.
	self assert: result statements first value = 1.
	self assert: result statements first value isInteger.
	self assert: result statements second isLiteral.
	self assert: result statements second value = 2.
	self assert: result statements second value isInteger! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 8/13/2011 20:50'!
testStatements3
	super testStatements3.
	self assert: result isSequence.
	self assert: result temporaries isEmpty.
	self assert: result statements size = 3.
	self assert: result statements first isLiteral.
	self assert: result statements first value = 1.
	self assert: result statements first value isInteger.
	self assert: result statements second isLiteral.
	self assert: result statements second value = 2.
	self assert: result statements second value isInteger.
	self assert: result statements third isLiteral.
	self assert: result statements third value = 3.
	self assert: result statements third value isInteger! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 8/13/2011 20:49'!
testStatements4
	super testStatements4.
	self assert: result isSequence.
	self assert: result temporaries isEmpty.
	self assert: result statements size = 3.
	self assert: result statements first isLiteral.
	self assert: result statements first value = 1.
	self assert: result statements first value isInteger.
	self assert: result statements second isLiteral.
	self assert: result statements second value = 2.
	self assert: result statements second value isInteger.
	self assert: result statements third isLiteral.
	self assert: result statements third value = 3.
	self assert: result statements third value isInteger! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 8/13/2011 20:49'!
testStatements5
	super testStatements5.
	self assert: result isSequence.
	self assert: result temporaries isEmpty.
	self assert: result statements size = 2.
	self assert: result statements first isLiteral.
	self assert: result statements first value = 1.
	self assert: result statements first value isInteger.
	self assert: result statements second isLiteral.
	self assert: result statements second value = 2.
	self assert: result statements second value isInteger! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 8/13/2011 20:49'!
testStatements6
	super testStatements6.
	self assert: result isSequence.
	self assert: result temporaries isEmpty.
	self assert: result statements size = 2.
	self assert: result statements first isLiteral.
	self assert: result statements first value = 1.
	self assert: result statements first value isInteger.
	self assert: result statements second isLiteral.
	self assert: result statements second value = 2.
	self assert: result statements second value isInteger
	! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 8/13/2011 21:21'!
testStatements7
	super testStatements7.
	self assert: result isSequence.
	self assert: result temporaries isEmpty.
	self assert: result statements size = 1.
	self assert: result statements first isLiteral.
	self assert: result statements first value = 1.
	self assert: result statements first value isInteger! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 8/13/2011 21:21'!
testStatements8
	super testStatements8.
	self assert: result isSequence.
	self assert: result temporaries isEmpty.
	self assert: result statements size = 1.
	self assert: result statements first isLiteral.
	self assert: result statements first value = 1.
	self assert: result statements first value isInteger! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testTemporaries1
	super testTemporaries1.
	self assert: result isSequence.
	self assert: result temporaries size = 1.
	self assert: result temporaries first isVariable.
	self assert: result temporaries first name = 'a'.
	self assert: result statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testTemporaries2
	super testTemporaries2.
	self assert: result isSequence.
	self assert: result temporaries size = 2.
	self assert: result temporaries first isVariable.
	self assert: result temporaries first name = 'a'.
	self assert: result temporaries second isVariable.
	self assert: result temporaries second name = 'b'.
	self assert: result statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testTemporaries3
	super testTemporaries3.
	self assert: result isSequence.
	self assert: result temporaries size = 3.
	self assert: result temporaries first isVariable.
	self assert: result temporaries first name = 'a'.
	self assert: result temporaries second isVariable.
	self assert: result temporaries second name = 'b'.
	self assert: result temporaries third isVariable.
	self assert: result temporaries third name = 'c'.
	self assert: result statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testVariable1
	super testVariable1.
	self assert: result isVariable.
	self assert: result name = 'trueBinding'! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testVariable2
	super testVariable2.
	self assert: result isVariable.
	self assert: result name = 'falseBinding'! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testVariable3
	super testVariable3.
	self assert: result isVariable.
	self assert: result name = 'nilly'! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testVariable4
	super testVariable4.
	self assert: result isVariable.
	self assert: result name = 'selfish'! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'lr 9/27/2009 12:42'!
testVariable5
	super testVariable5.
	self assert: result isVariable.
	self assert: result name = 'supernanny'! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'PetrSpacek 10/17/2012 15:20'!
testVariable6
	super testVariable6.
	PPCompoGrammar allowUnderscoreAssignment
		ifTrue: [ ^ self ].
	self assert: result isVariable.
	self assert: result name = 'super_nanny'! !

!PPCompoParserTests methodsFor: 'testing' stamp: 'PetrSpacek 10/17/2012 15:20'!
testVariable7
	super testVariable7.
	PPCompoGrammar allowUnderscoreAssignment
		ifTrue: [ ^ self ].
	self assert: result isVariable.
	self assert: result name = '__gen_var_123__'! !


!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral1
	super testArrayLiteral1.
	self assert: result isLiteral.
	self assert: result value = #()! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral10
	super testArrayLiteral10.
	self assert: result isLiteral.
	self assert: result value = #(#(1 2 ) #(1 2 3 ) )! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral11
	super testArrayLiteral11.
	self assert: result isLiteral.
	self assert: result value size = 2.
	self assert: (result value first isKindOf: ByteArray).
	self assert: result value first size = 2.
	self assert: (result value last isKindOf: ByteArray).
	self assert: result value last size = 3! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'TestRunner 10/23/2009 17:44'!
testArrayLiteral2
	super testArrayLiteral2.
	self assert: result isLiteral.
	self assert: result value = #(1)! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral3
	super testArrayLiteral3.
	self assert: result isLiteral.
	self assert: result value = #(1 2 )! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral4
	super testArrayLiteral4.
	self assert: result isLiteral.
	self assert: result value = #(true false nil )! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral5
	super testArrayLiteral5.
	self assert: result isLiteral.
	self assert: result value = #($a )! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral6
	super testArrayLiteral6.
	self assert: result isLiteral.
	self assert: result value = #(1.2 )! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral7
	super testArrayLiteral7.
	self assert: result isLiteral.
	self assert: result value = #(#size #at: #at:put: #'==' ).
	result value do: [ :each | self assert: each isSymbol ]! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral8
	super testArrayLiteral8.
	self assert: result isLiteral.
	self assert: result value = #('baz' ).
	self assert: result value first isString.
	self assert: result value first isSymbol not! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testArrayLiteral9
	super testArrayLiteral9.
	self assert: result isLiteral.
	self assert: result value = #(#(1 ) 2 )! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testByteLiteral1
	super testByteLiteral1.
	self assert: result isLiteral.
	self assert: (result value isKindOf: ByteArray).
	self assert: result value isEmpty! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testByteLiteral2
	super testByteLiteral2.
	self assert: result isLiteral.
	self assert: (result value isKindOf: ByteArray).
	self assert: result value size = 1.
	self assert: result value first = 0! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testByteLiteral3
	super testByteLiteral3.
	self assert: result isLiteral.
	self assert: (result value isKindOf: ByteArray).
	self assert: result value size = 1.
	self assert: result value first = 255! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testByteLiteral4
	super testByteLiteral4.
	self assert: result isLiteral.
	self assert: (result value isKindOf: ByteArray).
	self assert: result value size = 2.
	self assert: result value first = 1.
	self assert: result value last = 2! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testByteLiteral5
	super testByteLiteral5.
	self assert: result isLiteral.
	self assert: (result value isKindOf: ByteArray).
	self assert: result value size = 3.
	self assert: result value first = 10.
	self assert: result value second = 63.
	self assert: result value last = 255! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testCharLiteral1
	super testCharLiteral1.
	self assert: result isLiteral.
	self assert: result value = $a! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testCharLiteral2
	super testCharLiteral2.
	self assert: result isLiteral.
	self assert: result value = Character space! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testCharLiteral3
	super testCharLiteral3.
	self assert: result isLiteral.
	self assert: result value = $$! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:48'!
testNumberLiteral1
	super testNumberLiteral1.
	self assert: result isLiteral.
	self assert: result value = 0.
	self assert: result value isInteger! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:48'!
testNumberLiteral10
	super testNumberLiteral10.
	self assert: result isLiteral.
	self assert: result value = 10.
	self assert: result value isInteger! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:48'!
testNumberLiteral11
	super testNumberLiteral11.
	self assert: result isLiteral.
	self assert: result value = 511.
	self assert: result value isInteger! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:48'!
testNumberLiteral12
	super testNumberLiteral12.
	self assert: result isLiteral.
	self assert: result value = 175.
	self assert: result value isInteger! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:48'!
testNumberLiteral13
	super testNumberLiteral13.
	self assert: result isLiteral.
	self assert: result value = 202.9921875.
	self assert: result value isFloat! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:50'!
testNumberLiteral14
	super testNumberLiteral14.
	self assert: result isLiteral.
	self assert: result value floor = -9.
	self assert: result value isFloat! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:49'!
testNumberLiteral15
	super testNumberLiteral15.
	self assert: result isLiteral.
	self assert: result value = (1 / 2)! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:49'!
testNumberLiteral2
	super testNumberLiteral2.
	self assert: result isLiteral.
	self assert: result value = 0.1.
	self assert: result value isFloat! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:50'!
testNumberLiteral3
	super testNumberLiteral3.
	self assert: result isLiteral.
	self assert: result value = 123.
	self assert: result value isInteger! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:50'!
testNumberLiteral4
	super testNumberLiteral4.
	self assert: result isLiteral.
	self assert: result value = 123.456.
	self assert: result value isFloat! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:50'!
testNumberLiteral5
	super testNumberLiteral5.
	self assert: result isLiteral.
	self assert: result value = 0.
	self assert: result value isInteger! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:50'!
testNumberLiteral6
	super testNumberLiteral6.
	self assert: result isLiteral.
	self assert: result value = -0.1.
	self assert: result value isFloat! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:50'!
testNumberLiteral7
	super testNumberLiteral7.
	self assert: result isLiteral.
	self assert: result value = -123.
	self assert: result value isInteger! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:50'!
testNumberLiteral8
	super testNumberLiteral8.
	self assert: result isLiteral.
	self assert: result value = -123.
	self assert: result value isInteger! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:50'!
testNumberLiteral9
	super testNumberLiteral9.
	self assert: result isLiteral.
	self assert: result value = -123.456.
	self assert: result value isFloat! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testSpecialLiteral1
	super testSpecialLiteral1.
	self assert: result isLiteral.
	self assert: result value = true! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testSpecialLiteral2
	super testSpecialLiteral2.
	self assert: result isLiteral.
	self assert: result value = false! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testSpecialLiteral3
	super testSpecialLiteral3.
	self assert: result isLiteral.
	self assert: result value = nil! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testStringLiteral1
	super testStringLiteral1.
	self assert: result isLiteral.
	self assert: result value = ''! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testStringLiteral2
	super testStringLiteral2.
	self assert: result isLiteral.
	self assert: result value = 'ab'! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 9/27/2009 12:42'!
testStringLiteral3
	super testStringLiteral3.
	self assert: result isLiteral.
	self assert: result value = 'ab''cd'! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:47'!
testSymbolLiteral1
	super testSymbolLiteral1.
	self assert: result isLiteral.
	self assert: result value = #foo.
	self assert: result value isSymbol! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:47'!
testSymbolLiteral2
	super testSymbolLiteral2.
	self assert: result isLiteral.
	self assert: result value = #+.
	self assert: result value isSymbol! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:47'!
testSymbolLiteral3
	super testSymbolLiteral3.
	self assert: result isLiteral.
	self assert: result value = #key:.
	self assert: result value isSymbol! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:47'!
testSymbolLiteral4
	super testSymbolLiteral4.
	self assert: result isLiteral.
	self assert: result value = #key:value:.
	self assert: result value isSymbol! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:47'!
testSymbolLiteral5
	super testSymbolLiteral5.
	self assert: result isLiteral.
	self assert: result value = #'testing-result'.
	self assert: result value isSymbol! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'PetrSpacek 10/17/2012 15:20'!
testSymbolLiteral6
	super testSymbolLiteral6.
	PPCompoGrammar allowUnderscoreAssignment
		ifTrue: [ ^ self ].
	self assert: result isLiteral.
	self assert: result value = #__gen__binding.
	self assert: result value isSymbol! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:47'!
testSymbolLiteral7
	super testSymbolLiteral7.
	self assert: result isLiteral.
	self assert: result value = #fucker.
	self assert: result value isSymbol! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:47'!
testSymbolLiteral8
	super testSymbolLiteral8.
	self assert: result isLiteral.
	self assert: result value = #fucker.
	self assert: result value isSymbol! !

!PPCompoParserTests methodsFor: 'testing-literals' stamp: 'lr 8/14/2011 12:47'!
testSymbolLiteral9
	super testSymbolLiteral9.
	self assert: result isLiteral.
	self assert: result value = #fucker.
	self assert: result value isSymbol! !


!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testBinaryExpression1
	super testBinaryExpression1.
	self assert: result isMessage.
	self assert: result receiver isLiteral.
	self assert: result receiver value = 1.
	self assert: result arguments size = 1.
	self assert: result arguments first isLiteral.
	self assert: result arguments first value = 2! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testBinaryExpression2
	super testBinaryExpression2.
	self assert: result isMessage.
	self assert: result receiver isMessage.
	self assert: result receiver receiver isLiteral.
	self assert: result receiver receiver value = 1.
	self assert: result receiver arguments size = 1.
	self assert: result receiver arguments first isLiteral.
	self assert: result receiver arguments first value = 2.
	self assert: result arguments size = 1.
	self assert: result arguments first isLiteral.
	self assert: result arguments first value = 3! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 8/11/2011 23:27'!
testBinaryExpression3
	super testBinaryExpression3.
	self assert: result isMessage.
	self assert: result receiver isLiteral.
	self assert: result receiver value = 1.
	self assert: result selector = #//.
	self assert: result arguments size = 1.
	self assert: result arguments first isLiteral.
	self assert: result arguments first value = 2! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 8/11/2011 23:28'!
testBinaryExpression4
	super testBinaryExpression4.
	self assert: result isMessage.
	self assert: result receiver isLiteral.
	self assert: result receiver value = 1.
	self assert: result selector = #--.
	self assert: result arguments size = 1.
	self assert: result arguments first isLiteral.
	self assert: result arguments first value = 2! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 8/11/2011 23:27'!
testBinaryExpression5
	super testBinaryExpression5.
	self assert: result isMessage.
	self assert: result receiver isLiteral.
	self assert: result receiver value = 1.
	self assert: result selector = #==>.
	self assert: result arguments size = 1.
	self assert: result arguments first isLiteral.
	self assert: result arguments first value = 2! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testBinaryMethod1
	super testBinaryMethod1.
	self assert: result isMethod.
	self assert: result selector = #+.
	self assert: result arguments size = 1.
	self assert: result arguments first isVariable.
	self assert: result arguments first name = 'a'.
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testBinaryMethod2
	super testBinaryMethod2.
	self assert: result isMethod.
	self assert: result selector = #+.
	self assert: result arguments size = 1.
	self assert: result arguments first isVariable.
	self assert: result arguments first name = 'a'.
	self assert: result body temporaries size = 1.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testBinaryMethod3
	super testBinaryMethod3.
	self assert: result isMethod.
	self assert: result selector = #+.
	self assert: result arguments size = 1.
	self assert: result arguments first isVariable.
	self assert: result arguments first name = 'a'.
	self assert: result body temporaries isEmpty.
	self assert: result body statements size = 1! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testBinaryMethod4
	super testBinaryMethod4.
	self assert: result isMethod.
	self assert: result selector = #+.
	self assert: result arguments size = 1.
	self assert: result arguments first isVariable.
	self assert: result arguments first name = 'a'.
	self assert: result body temporaries size = 1.
	self assert: result body statements size = 1! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 8/11/2011 23:29'!
testBinaryMethod5
	super testBinaryMethod5.
	self assert: result isMethod.
	self assert: result selector = #--.
	self assert: result arguments size = 1.
	self assert: result arguments first isVariable.
	self assert: result arguments first name = 'a'.
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testCascadeExpression1
	super testCascadeExpression1.
	self assert: result isCascade.
	self assert: result receiver isLiteral.
	self assert: result messages size = 2.
	self assert: result messages first receiver = result receiver.
	self assert: result messages first selector = #abs.
	self assert: result messages second receiver = result receiver.
	self assert: result messages second selector = #negated! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testCascadeExpression2
	super testCascadeExpression2.
	self assert: result isCascade.
	self assert: result receiver isMessage.
	self assert: result receiver receiver isLiteral.
	self assert: result receiver receiver value = 1.
	self assert: result receiver selector = #abs.
	self assert: result messages size = 3.
	self assert: result messages first receiver = result receiver.
	self assert: result messages first selector = #negated.
	self assert: result messages second receiver = result receiver.
	self assert: result messages second selector = #raisedTo:.
	self assert: result messages third receiver = result receiver.
	self assert: result messages third selector = #negated! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testCascadeExpression3
	super testCascadeExpression3.
	self assert: result isCascade.
	self assert: result receiver isLiteral.
	self assert: result receiver value = 1.
	self assert: result messages size = 2.
	self assert: result messages first receiver = result receiver.
	self assert: result messages first selector = #+.
	self assert: result messages first arguments size = 1.
	self assert: result messages second receiver = result receiver.
	self assert: result messages second selector = #-.
	self assert: result messages second arguments size = 1! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testKeywordExpression1
	super testKeywordExpression1.
	self assert: result isMessage.
	self assert: result receiver isLiteral.
	self assert: result receiver value = 1.
	self assert: result selector = #to:.
	self assert: result arguments size = 1.
	self assert: result arguments first isLiteral.
	self assert: result arguments first value = 2! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testKeywordExpression2
	super testKeywordExpression2.
	self assert: result isMessage.
	self assert: result receiver isLiteral.
	self assert: result selector = #to:by:.
	self assert: result arguments size = 2.
	self assert: result arguments first isLiteral.
	self assert: result arguments first value = 2.
	self assert: result arguments second isLiteral.
	self assert: result arguments second value = 3! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testKeywordExpression3
	super testKeywordExpression3.
	self assert: result isMessage.
	self assert: result receiver isLiteral.
	self assert: result selector = #to:by:do:.
	self assert: result arguments size = 3.
	self assert: result arguments first isLiteral.
	self assert: result arguments first value = 2.
	self assert: result arguments second isLiteral.
	self assert: result arguments second value = 3.
	self assert: result arguments third isLiteral.
	self assert: result arguments third value = 4! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testKeywordMethod1
	super testKeywordMethod1.
	self assert: result isMethod.
	self assert: result selector = #to:.
	self assert: result arguments size = 1.
	self assert: result arguments first isVariable.
	self assert: result arguments first name = 'a'.
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testKeywordMethod2
	super testKeywordMethod2.
	self assert: result isMethod.
	self assert: result selector = #to:do:.
	self assert: result arguments size = 2.
	self assert: result arguments first isVariable.
	self assert: result arguments first name = 'a'.
	self assert: result arguments second isVariable.
	self assert: result arguments second name = 'b'.
	self assert: result body temporaries size = 1.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testKeywordMethod3
	super testKeywordMethod3.
	self assert: result isMethod.
	self assert: result selector = #to:do:by:.
	self assert: result arguments size = 3.
	self assert: result arguments first isVariable.
	self assert: result arguments first name = 'a'.
	self assert: result arguments second isVariable.
	self assert: result arguments second name = 'b'.
	self assert: result arguments third isVariable.
	self assert: result arguments third name = 'c'.
	self assert: result body temporaries isEmpty.
	self assert: result body statements size = 1! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testKeywordMethod4
	super testKeywordMethod4.
	self assert: result isMethod.
	self assert: result selector = #to:do:by:.
	self assert: result arguments size = 3.
	self assert: result arguments first isVariable.
	self assert: result arguments first name = 'a'.
	self assert: result arguments second isVariable.
	self assert: result arguments second name = 'b'.
	self assert: result arguments third isVariable.
	self assert: result arguments third name = 'c'.
	self assert: result body temporaries size = 1.
	self assert: result body statements size = 1! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testUnaryExpression1
	super testUnaryExpression1.
	self assert: result isMessage.
	self assert: result receiver isLiteral.
	self assert: result selector = #abs.
	self assert: result arguments isEmpty! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testUnaryExpression2
	super testUnaryExpression2.
	self assert: result isMessage.
	self assert: result receiver isMessage.
	self assert: result receiver receiver isLiteral.
	self assert: result receiver receiver value = 1.
	self assert: result receiver selector = #abs.
	self assert: result receiver arguments isEmpty.
	self assert: result selector = #negated.
	self assert: result arguments isEmpty! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testUnaryMethod1
	super testUnaryMethod1.
	self assert: result isMethod.
	self assert: result selector = #abs.
	self assert: result arguments isEmpty.
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testUnaryMethod2
	super testUnaryMethod2.
	self assert: result isMethod.
	self assert: result selector = #abs.
	self assert: result arguments isEmpty.
	self assert: result body temporaries size = 1.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testUnaryMethod3
	super testUnaryMethod3.
	self assert: result isMethod.
	self assert: result selector = #abs.
	self assert: result arguments isEmpty.
	self assert: result body temporaries isEmpty.
	self assert: result body statements size = 1! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testUnaryMethod4
	super testUnaryMethod4.
	self assert: result isMethod.
	self assert: result selector = #abs.
	self assert: result arguments isEmpty.
	self assert: result body temporaries size = 1.
	self assert: result body statements size = 1! !

!PPCompoParserTests methodsFor: 'testing-messages' stamp: 'lr 9/27/2009 12:42'!
testUnaryMethod5
	super testUnaryMethod5.
	self assert: result isMethod.
	self assert: result selector = #abs.
	self assert: result arguments isEmpty.
	self assert: result body temporaries size = 1.
	self assert: result body statements isEmpty! !


!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma1
	super testPragma1.
	self 
		assert: result pragmas
		format: #('<foo>' ).
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma10
	super testPragma10.
	self 
		assert: result pragmas
		format: #('<foo: #bar>' ).
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma11
	super testPragma11.
	self 
		assert: result pragmas
		format: #('<foo: true>' ).
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma12
	super testPragma12.
	self 
		assert: result pragmas
		format: #('<foo: false>' ).
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma13
	super testPragma13.
	self 
		assert: result pragmas
		format: #('<foo: nil>' ).
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma14
	super testPragma14.
	self 
		assert: result pragmas
		format: #('<foo: #()>' ).
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma15
	super testPragma15.
	self 
		assert: result pragmas
		format: #('<foo: #()>' ).
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 11/23/2010 14:07'!
testPragma16
	super testPragma16.
	self 
		assert: result pragmas
		format: #('< + 1>' ).
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma2
	super testPragma2.
	self 
		assert: result pragmas
		format: #('<foo>' '<bar>' ).
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma3
	super testPragma3.
	self 
		assert: result pragmas
		format: #('<foo>' ).
	self assert: result body temporaries size = 1.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma4
	super testPragma4.
	self 
		assert: result pragmas
		format: #('<foo>' ).
	self assert: result body temporaries size = 1.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma5
	super testPragma5.
	self 
		assert: result pragmas
		format: #('<foo>' '<bar>' ).
	self assert: result body temporaries size = 1.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma6
	super testPragma6.
	self 
		assert: result pragmas
		format: #('<foo: 1>' ).
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma7
	super testPragma7.
	self 
		assert: result pragmas
		format: #('<foo: 1.2>' ).
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma8
	super testPragma8.
	self 
		assert: result pragmas
		format: #('<foo: ''bar''>' ).
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !

!PPCompoParserTests methodsFor: 'testing-pragmas' stamp: 'lr 9/27/2009 12:42'!
testPragma9
	super testPragma9.
	self 
		assert: result pragmas
		format: #('<foo: #bar>' ).
	self assert: result body temporaries isEmpty.
	self assert: result body statements isEmpty! !
